@@ -136,7 +136,7 @@ class SerialReader:
                                         can_filters=filters,
                                         bustype='socketcan')
                 bus.send(set_id_msg)
-            except can.CanError as e:
+            except (can.CanError, os.error) as e:
                 logging.warn("%sUnable to open CAN port: %s",
                              self.warn_prefix, e)
                 self.reactor.pause(self.reactor.monotonic() + 5.)
@@ -226,6 +226,8 @@ class SerialReader:
         return self.reactor
     def get_msgparser(self):
         return self.msgparser
+    def get_serialqueue(self):
+        return self.serialqueue
     def get_default_command_queue(self):
         return self.default_cmd_queue
     # Serial response callbacks
